@@ -1,9 +1,19 @@
+# frozen_string_literal: true
+
 require "test_helper"
 require "fileutils"
 
 class TestReloading < LoaderTest
   module Namespace; end
 
+  def silence_exceptions_in_threads
+    original_report_on_exception = Thread.report_on_exception
+    Thread.report_on_exception = false
+    yield
+  ensure
+    Thread.report_on_exception = original_report_on_exception
+  end
+
   test "enabling reloading after setup raises" do
     e = assert_raises(Zeitwerk::Error) do
       loader = Zeitwerk::Loader.new
@@ -187,4 +197,33 @@ class TestReloading < LoaderTest
       assert_equal 2, $test_eager_load_after_reload
     end
   end
+
+  test "reload recovers from name errors (w/o on_unload callbacks)" do
+    on_teardown { remove_const :Y }
+
+    files = [["x.rb", "Y = :typo"]]
+    with_setup(files) do
+      assert_raises(Zeitwerk::NameError) { X }
+
+      loader.reload
+      File.write("x.rb", "X = true")
+
+      assert X
+    end
+  end
+
+  test "reload recovers from name errors (w/ on_unload callbacks)" do
+    on_teardown { remove_const :Y }
+
+    files = [["x.rb", "Y = :typo"]]
+    with_setup(files) do
+      loader.on_unload {}
+      assert_raises(Zeitwerk::NameError) { X }
+
+      loader.reload
+      File.write("x.rb", "X = true")
+
+      assert X
+    end
+  end
 end
