@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 class LoaderTest < Minitest::Test
   TMP_DIR = File.expand_path("../tmp", __dir__)
 
@@ -29,7 +31,9 @@ class LoaderTest < Minitest::Test
 
   def reset_registry
     Zeitwerk::Registry.loaders.clear
-    Zeitwerk::Registry.loaders_managing_gems.clear
+    Zeitwerk::Registry.gem_loaders_by_root_file.clear
+    Zeitwerk::Registry.autoloads.clear
+    Zeitwerk::Registry.inceptions.clear
   end
 
   def reset_explicit_namespace
@@ -56,20 +60,18 @@ class LoaderTest < Minitest::Test
         FileUtils.mkdir_p(File.dirname(fname))
         File.write(fname, contents)
       end
-
-      begin
-        yield
-      ensure
-        mkdir_test if rm
-      end
+      yield
     end
+  ensure
+    mkdir_test if rm
   end
 
   def with_load_path(dirs = loader.dirs)
-    Array(dirs).each { |dir| $LOAD_PATH.push(dir) }
+    dirs = Array(dirs).map { |dir| File.expand_path(dir) }
+    dirs.each { |dir| $LOAD_PATH.push(dir) }
     yield
   ensure
-    Array(dirs).each { |dir| $LOAD_PATH.delete(dir) }
+    dirs.each { |dir| $LOAD_PATH.delete(dir) }
   end
 
   def with_setup(files, dirs: ".", namespace: Object, load_path: nil, rm: true)
@@ -83,4 +85,8 @@ class LoaderTest < Minitest::Test
       end
     end
   end
+
+  def assert_abspath(expected, actual)
+    assert_equal(File.expand_path(expected, TMP_DIR), actual)
+  end
 end
